@@ -21,17 +21,20 @@
 #include "fifteenpuzzleplugin.h"
 #include "fifteenimageprovider.h"
 
-#include <QtQml>
+// Qt
+#include <QQmlEngine>
+#include <QDebug>
 
 void FifteenPuzzlePlugin::registerTypes(const char* uri)
 {
     Q_UNUSED(uri);
-    Q_ASSERT(uri == QStringLiteral("org.kde.plasma.private.fifteenpuzzle"));
-    qmlRegisterTypeNotAvailable(uri, 0, 1, "fifteenpuzzle", "fifteenpuzzle");
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.fifteenpuzzle"));
+    // Do some dummy registration, otherwise the plugin will be ignored at runtime
+    qmlRegisterTypeNotAvailable(uri, 0, 1, "FifteenPuzzle", QStringLiteral("fifteenpuzzle"));
 }
 
 void FifteenPuzzlePlugin::initializeEngine(QQmlEngine * engine, const char * uri)
 {
     qDebug() << "initializeEngine called, uri is " << uri;
-    engine->addImageProvider("fifteenpuzzle", new FifteenImageProvider());
+    engine->addImageProvider(QStringLiteral("fifteenpuzzle"), new FifteenImageProvider());
 }
