@@ -31,8 +31,8 @@ class FifteenPuzzlePlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    void registerTypes(const char* uri) Q_DECL_OVERRIDE;
-    void initializeEngine(QQmlEngine * engine, const char * uri) Q_DECL_OVERRIDE;
+    void registerTypes(const char* uri) override;
+    void initializeEngine(QQmlEngine * engine, const char * uri) override;
 
 };
 
