@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
  ***************************************************************************/
 
-#ifndef SYSTEMTRAY_H
-#define SYSTEMTRAY_H
+#ifndef GROUPINGCONTAINMENT_H
+#define GROUPINGCONTAINMENT_H
 
 #include <Plasma/Containment>
 
@@ -29,7 +29,7 @@ class GroupingContainment : public Plasma::Containment
 {
     Q_OBJECT
 public:
-    GroupingContainment( QObject *parent, const QVariantList &args );
+    explicit GroupingContainment( QObject *parent, const QVariantList &args );
     ~GroupingContainment() override;
 
     void init() override;
